k4a_image_reference

Function k4a_image_reference 

pub unsafe extern "C" fn k4a_image_reference(
    image_handle: k4a_image_t,
)
Add a reference to the k4a_image_t.

\param image_handle Handle of the image for which the get operation is performed on.

\remarks References manage the lifetime of the object. When the references reach zero the object is destroyed. A caller must not access the object after its reference is released.

\relates k4a_image_t

\xmlonly k4a.h (include k4a/k4a.h) k4a.lib k4a.dll \endxmlonly