pub type k4a_capture_t = *mut _k4a_capture_t;Expand description
\class k4a_capture_t k4a.h <k4a/k4a.h> Handle to an Azure Kinect capture.
\remarks A capture represents a set of images that were captured by a device at approximately the same time. A capture may have a color, IR, and depth image. A capture may have up to one image of each type. A capture may have no image for a given type as well.
\remarks Captures also store a temperature value which represents the temperature of the device at the time of the capture.
\remarks While all the images associated with the capture were collected at approximately the same time, each image has an individual timestamp which may differ from each other. If the device was configured to capture depth and color images separated by a delay, k4a_device_get_capture() will return a capture containing both image types separated by the configured delay.
\remarks The capture will add a reference on any \ref k4a_image_t that is added to it with one of the setters like k4a_capture_set_color_image(). If an existing image is being replaced, the previous image will have the reference released.
\remarks Once all references to the \ref k4a_capture_t are released, the capture will release the references it holds on any \ref k4a_image_t that are associated with it.
\remarks When a capture returns an image to the caller with an accessor like k4a_capture_get_color_image(), a new reference is added to the \ref k4a_image_t and the caller is responsible for releasing that reference with k4a_image_release().
\remarks Empty captures are created with k4a_capture_create().
\remarks Captures can be obtained from a device using k4a_device_get_capture().
\remarks The caller must call k4a_capture_release() to release its reference to any \ref k4a_capture_t that it receives from an Azure Kinect API.
\remarks Additional references to the capture may be obtained with k4a_capture_reference().
\remarks An invalid k4a_capture_t will be set to 0.
\see k4a_image_t
\xmlonly